@@ -139,7 +139,7 @@ class ApplicationCode(
     '''(experimental) Code configuration providing the location to a Flink application JAR file.
 
     :stability: experimental
-    :exampleMetadata: lit=test/integ.application.lit.ts ! show
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show infused
 
     Example::
 
@@ -522,7 +522,7 @@ class ApplicationProps:
         :param snapshots_enabled: (experimental) Determines if Flink snapshots are enabled. Default: true
 
         :stability: experimental
-        :exampleMetadata: lit=test/integ.application.lit.ts ! show
+        :exampleMetadata: lit=test/integ.application.lit.ts ! show infused
 
         Example::
 
@@ -891,6 +891,7 @@ class LogLevel(enum.Enum):
     '''(experimental) Available log levels for Flink applications.
 
     :stability: experimental
+    :exampleMetadata: infused
 
     Example::
 
@@ -939,6 +940,7 @@ class MetricsLevel(enum.Enum):
     '''(experimental) Granularity of metrics sent to CloudWatch.
 
     :stability: experimental
+    :exampleMetadata: infused
 
     Example::
 
@@ -992,6 +994,7 @@ class PropertyGroups:
         '''(experimental) Interface for building AWS::KinesisAnalyticsV2::Application PropertyGroup configuration.
 
         :stability: experimental
+        :exampleMetadata: infused
 
         Example::
 
@@ -1030,7 +1033,7 @@ class Runtime(
     '''(experimental) Available Flink runtimes for Kinesis Analytics.
 
     :stability: experimental
-    :exampleMetadata: lit=test/integ.application.lit.ts ! show
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show infused
 
     Example::
 
@@ -1115,7 +1118,7 @@ class Application(
     '''(experimental) The L2 construct for Flink Kinesis Data Applications.
 
     :stability: experimental
-    :exampleMetadata: lit=test/integ.application.lit.ts ! show
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show infused
     :resource: AWS::KinesisAnalyticsV2::Application
 
     Example::
